AppAuthenticator class
Properties
- afterResultScreen ↔ Widget?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyMessage(
String message) → void -
removeMessageListener(
) → void -
setMessageListener(
void listener(String message)) → void -
toString(
) → String -
A string representation of this object.
inherited
-
validateAndInitialize(
{required BuildContext context, required String token, required String flag, Widget? afterResultScreen}) → Future< void> -
validateDomain(
{required String domainAppId, required String token, required String flag}) → Future< bool>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
final