APIManager class

Properties

authToken String
final
baseURL String
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request({required String endpoint, HTTPMethod method = HTTPMethod.get, Map<String, dynamic>? parameters}) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared APIManager
no setter