PassportVerificationWidget class

Inheritance

Constructors

PassportVerificationWidget({Key? key, required Widget documentImage, required Widget nfcLeftImageView, required Widget nfcRightImageView, required double nfcFaceSimilarity, required bool selfieMatchedWithDocument, required String genderConsistency, required int ageEstimate, required double passiveLivenessResult, required double ocrConfidence, required bool chipAuthenticated, required bool isDocumentExpired, required bool isDocumentTampered, VoidCallback? onHomePressed, VoidCallback? onNextPressed})
const

Properties

ageEstimate int
final
chipAuthenticated bool
final
documentImage Widget
final
genderConsistency String
final
hashCode int
The hash code for this object.
no setterinherited
isDocumentExpired bool
final
isDocumentTampered bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
nfcFaceSimilarity double
final
nfcLeftImageView Widget
final
nfcRightImageView Widget
final
ocrConfidence double
final
onHomePressed VoidCallback?
final
onNextPressed VoidCallback?
final
passiveLivenessResult double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfieMatchedWithDocument bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited